package com.hw.dms.mapper;

import java.util.List;
import com.hw.dms.domain.DmsBaseInspectRoute;

/**
 * 巡检线路信息Mapper接口
 *
 * @author Open Platform
 * @date 2024-01-16
 */
public interface DmsBaseInspectRouteMapper
{
    /**
     * 查询巡检线路信息
     *
     * @param inspectRouteId 巡检线路信息主键
     * @return 巡检线路信息
     */
    public DmsBaseInspectRoute selectDmsBaseInspectRouteByInspectRouteId(Long inspectRouteId);

    /**
     * 查询巡检线路信息列表
     *
     * @param dmsBaseInspectRoute 巡检线路信息
     * @return 巡检线路信息集合
     */
    public List<DmsBaseInspectRoute> selectDmsBaseInspectRouteList(DmsBaseInspectRoute dmsBaseInspectRoute);

    /**
     * 新增巡检线路信息
     *
     * @param dmsBaseInspectRoute 巡检线路信息
     * @return 结果
     */
    public int insertDmsBaseInspectRoute(DmsBaseInspectRoute dmsBaseInspectRoute);

    /**
     * 修改巡检线路信息
     *
     * @param dmsBaseInspectRoute 巡检线路信息
     * @return 结果
     */
    public int updateDmsBaseInspectRoute(DmsBaseInspectRoute dmsBaseInspectRoute);

    /**
     * 删除巡检线路信息
     *
     * @param inspectRouteId 巡检线路信息主键
     * @return 结果
     */
    public int deleteDmsBaseInspectRouteByInspectRouteId(Long inspectRouteId);

    /**
     * 批量删除巡检线路信息
     *
     * @param inspectRouteIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDmsBaseInspectRouteByInspectRouteIds(Long[] inspectRouteIds);

    Long selectAmountByInspectRouteId(Long InspectRouteId);
}
